(define-module (skg packages node-modules)
  #:use-module (guix)
  #:use-module (guix build-system node)
  #:use-module (guix git-download)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module (gnu packages)
  #:use-module (gnu packages node-xyz))

(define-public node-argparse
  (package
    (name "node-argparse")
    (version "2.0.1")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/nodeca/argparse.git")
              (commit "2.0.1")))
        (file-name (git-file-name name version))
        (sha256 (base32 "0wz8i7w0f633r9l81nm1is7wv8a9k90hgxi8x01xpvpwmhl6xvfx"))))
    (build-system node-build-system)
    (arguments
     '(#:tests? #f
       #:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("@babel/eslint-parser"
                                             "@babel/plugin-syntax-class-properties"
                                             "eslint"
                                             "mocha"
                                             "nyc")))))))
    (home-page "https://github.com/nodeca/argparse")
    (synopsis "CLI arguments parser for node.js. JS port of python's argparse module.")
    (description "CLI arguments parser for node.js, with sub-commands support. Port of python's argparse")
    (license license:psfl)))

(define-public node-end-of-stream
  (package
    (name "node-end-of-stream")
    (version "1.4.4")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/mafintosh/end-of-stream.git")
              (commit "v1.4.4")))
        (file-name (git-file-name name version))
        (sha256 (base32 "0241fxmc30hzxcidyvkd0bylsdcq20nf9yy6v5cgiwp9xq7bpc3a"))))
    (inputs
     (list node-once))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("tape")))))))
    (home-page "https://github.com/mafintosh/end-of-stream")
    (synopsis "Call a callback when a readable/writable/duplex stream has completed or failed. ")
    (description "A node module that calls a callback when a readable/writable/duplex stream has completed or failed.")
    (license license:expat)))

(define-public node-stream-exhaust
  (package
    (name "node-stream-exhaust")
    (version "1.0.2")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/chrisdickinson/stream-exhaust.git")
              (commit "v1.0.2")))
        (file-name (git-file-name name version))
        (sha256 (base32 "0ggdlx0jlkyxi2wszw7j45gz3v8g9rh8613nf6dr579yp7bza40c"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("readable-stream"
					     "tape"
					     "through2")))))))

    (home-page "https://github.com/chrisdickinson/stream-exhaust")
    (synopsis " Ensure that a stream is flowing data without mutating it ")
    (description "Ensure that the provided stream is flowing data, even if the stream hasn't been piped to another stream.")
    (license license:expat)))

(define-public node-async-done
  (package
    (name "node-async-done")
    (version "2.0.0")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/gulpjs/async-done.git")
              (commit "v2.0.0")))
        (file-name (git-file-name name version))
        (sha256 (base32 "198l763qspdcwkgd5gggwhpi4l8skmzj7d8alli7abkqs681wrxr"))))
    (build-system node-build-system)
    (inputs (list node-end-of-stream node-once node-stream-exhaust))
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("@types/node"
					     "eslint"
					     "eslint-config-gulp"
					     "eslint-plugin-node"
					     "expect"
					     "mocha"
					     "nyc"
					     "pumpify"
					     "rxjs"
					     "streamx"
					     "through2"
					     "typescript")))))))

    (home-page "https://github.com/gulpjs/async-done")
    (synopsis " Allows libraries to handle various caller provided asynchronous functions uniformly. Maps promises, observables, child processes and streams, and callbacks to callback style. ")
    (description "Allows libraries to handle various caller provided asynchronous functions uniformly. Maps promises, observables, child processes and streams, and callbacks to callback style.")
    (license license:expat)))

(define-public node-picomatch
  (package
    (name "node-picomatch")
    (version "2.3.1")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/micromatch/picomatch.git")
              (commit "2.3.1")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1qvdck71fcfp1j2hmw4ngidg908s3wj0jd99aggi8rl9cfnva3lr"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("eslint"
					     "fill-range"
					     "gulp-format-md"
					     "mocha"
					     "nyc"
					     "time-require")))))))

    (home-page "https://github.com/micromatch/picomatch")
    (synopsis " Blazing fast and accurate glob matcher written in JavaScript.")
    (description "Blazing fast and accurate glob matcher written JavaScript, with no dependencies and full support for standard and extended Bash glob features, including braces, extglobs, POSIX brackets, and regular expressions.")
    (license license:expat)))


(define-public node-anymatch
  (package
    (name "node-anymatch")
    (version "3.1.3")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/micromatch/anymatch.git")
              (commit "v3.1.3")))
        (file-name (git-file-name name version))
        (sha256 (base32 "0gggqaysdpznkl2i97hgd75xf5pwwj3c8f9iqani6wr5kb6c6xjj"))))
    (build-system node-build-system)
    (inputs (list node-normalize-path node-picomatch))
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("mocha"
					     "nyc")))))))

    (home-page "https://github.com/micromatch/anymatch")
    (synopsis "Matches strings against configurable strings, globs, regular expressions, and/or functions ")
    (description "Javascript module to match a string against a regular expression, glob, string, or function that takes the string as an argument and returns a truthy or falsy value. The matcher can also be an array of any or all of these. Useful for allowing a very flexible user-defined config to define things like file paths.")
    (license license:isc)))

(define-public node-is-number
  (package
    (name "node-is-number")
    (version "7.0.0")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/jonschlinkert/is-number.git")
              (commit "7.0.0")))
        (file-name (git-file-name name version))
        (sha256 (base32 "13sy484inzcs6xk4aisv1yqs5dsh19pr4xhq9s4svcnh6hlhqww9"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("ansi"
					     "benchmark"
					     "gulp-format-md"
					     "mocha")))))))


    (home-page "https://github.com/jonschlinkert/is-number")
    (synopsis "Returns true if the value is a finite number.")
    (description "JavaScript/Node.js utility. Returns `true` if the value is a number or string number. Useful for checking regex match results, user input, parsed strings, etc. ")
    (license license:expat)))

(define-public node-to-regex-range
  (package
    (name "node-to-regex-range")
    (version "5.0.1")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/micromatch/to-regex-range.git")
              (commit "5.0.1")))
        (file-name (git-file-name name version))
        (sha256 (base32 "02xhjynmsnjpy56dwbhnxikx1l27sjvsw8vfm2bhil3m2f27bhp4"))))
    (build-system node-build-system)
    (inputs (list node-is-number))
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("fill-range"
					     "gulp-format-md"
					     "mocha"
					     "text-table"
					     "time-diff")))))))


    (home-page "https://github.com/micromatch/to-regex-range")
    (synopsis "Pass two numbers, get a regex-compatible source string for matching ranges. Validated against more than 2.78 million test assertions.")
    (description "Pass two numbers, get a regex-compatible source string for matching ranges. Fast compiler, optimized regex, and validated against more than 2.78 million test assertions. Useful for creating regular expressions to validate numbers, ranges, years, etc. ")
    (license license:expat)))

(define-public node-fill-range
  (package
    (name "node-fill-range")
    (version "7.0")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/jonschlinkert/fill-range.git")
              (commit "7.0")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1fsv3f8m6xi7xa5vyyw4hd2pgrmbdd55gwnc97mr6p3q93ml9gsk"))))
    (build-system node-build-system)
    (inputs (list node-to-regex-range))
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("gulp-format-md"
					     "mocha")))))))


    (home-page "https://github.com/jonschlinkert/fill-range")
    (synopsis "Fill in a range of numbers or letters, positive or negative, optionally passing an increment or multiplier to use.")
    (description "Fill in a range of numbers or letters, optionally passing an increment or step to use, or create a regex-compatible range with options.toRegex")
    (license license:expat)))

(define-public node-braces
  (package
    (name "node-braces")
    (version "3.0.2")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/micromatch/braces.git")
              (commit "3.0.2")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1y7h4jqpglhcrzvhbg1s018bj34wvr1q9k30xsxn4yqxaga995my"))))
    (build-system node-build-system)
    (inputs (list node-fill-range))
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("ansi-colors"
					     "bash-path"
					     "gulp-format-md"
					     "mocha")))))))


    (home-page "https://github.com/micromatch/braces")
    (synopsis "Bash-like brace expansion, implemented in JavaScript. Safer than other brace expansion libs, with complete support for the Bash 4.3 braces specification, without sacrificing speed.")
    (description "Faster brace expansion for node.js. Besides being faster, braces is not subject to DoS attacks like minimatch, is more accurate, and has more complete support for Bash 4.3. ")
    (license license:expat)))

(define-public node-is-glob-ext
  (package
    (name "node-is-glob-ext")
    (version "2.1.1")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/micromatch/is-extglob.git")
              (commit "2.1.1")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1nx8nxgm7gkdlwdnfd5lp3ng1lymla8gqfqsg9m11v65dz3q9j0q"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("gulp-format-md"
					     "mocha")))))))


    (home-page "https://github.com/micromatch/is-extglob")
    (synopsis "Returns true if a string has an extglob ")
    (description "Returns true if a string has an extglob ")
    (license license:expat)))

(define-public node-is-glob
  (package
    (name "node-is-glob")
    (version "4.0.3")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/micromatch/is-glob.git")
              (commit "v4.0.3")))
        (file-name (git-file-name name version))
        (sha256 (base32 "0iy5776bifm2y1c6a27gv23h6r8fyzyr0bsm7vdbwcv5w7ivfyal"))))
    (build-system node-build-system)
    (inputs (list node-is-glob-ext))
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("gulp-format-md"
					     "mocha")))))))


    (home-page "https://github.com/micromatch/is-glob")
    (synopsis "If you use globs, this will make your code faster.")
    (description "If you use globs, this will make your code faster. Returns `true` if the given string looks like a glob pattern or an extglob pattern. This makes it easy to create code that only uses external modules like node-glob when necessary, resulting in much faster code execution and initialization time, and a better user experience.")
    (license license:expat)))

(define-public node-glob-parent
  (package
    (name "node-glob-parent")
    (version "6.0.2")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/gulpjs/glob-parent.git")
              (commit "v6.0.2")))
        (file-name (git-file-name name version))
        (sha256 (base32 "0k52vsbz7j6d1g60ag2xqdchklgd8g5b5h5vb48268chhq51f2f0"))))
    (build-system node-build-system)
    (inputs (list node-is-glob))
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("eslint"
					     "eslint-config-gulp"
					     "expect"
					     "mocha"
					     "nyc")))))))
    (home-page "https://github.com/gulpjs/glob-parent")
    (synopsis " Extract the non-magic parent path from a glob string.")
    (description "Extract the non-magic parent path from a glob string.")
    (license license:isc)))


(define-public node-binary-extensions
  (package
    (name "node-binary-extensions")
    (version "2.2.0")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/sindresorhus/binary-extensions.git")
              (commit "v2.2.0")))
        (file-name (git-file-name name version))
        (sha256 (base32 "0q873q8018glxsrgkv6jwknmblh556kpx2h182cbn3s411qja5hf"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("ava"
					     "tsd"
					     "xo")))))))

    (home-page "https://github.com/sindresorhus/binary-extensions")
    (synopsis " List of binary file extensions")
    (description " List of binary file extensions. The list is just a JSON file and can be used anywhere.")
    (license license:expat)))

(define-public node-is-binary-path
  (package
    (name "node-is-binary-path")
    (version "2.1.0")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/sindresorhus/is-binary-path.git")
              (commit "v2.1.0")))
        (file-name (git-file-name name version))
        (sha256 (base32 "18wfddnll7azf165z7ijrmjggqv2nngi56q8akw97xikvfkp3vby"))))
    (build-system node-build-system)
    (inputs (list node-binary-extensions))
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("ava"
					     "tsd"
					     "xo")))))))

    (home-page "https://github.com/sindresorhus/is-binary-path")
    (synopsis "Check if a file path is a binary file")
    (description "Check if a file path is a binary file")
    (license license:expat)))

(define-public node-readdirp
  (package
    (name "node-readdirp")
    (version "3.6.0")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/paulmillr/readdirp.git")
              (commit "3.6.0")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1kixaw6b9d3y2g9h55x6hdg5d6ld5mj87p8jcplq99wmnbv1i1p9"))))
    (build-system node-build-system)
    (inputs (list node-picomatch))
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("@types/node"
					     "chai"
					     "chai-subset"
					     "eslint"
					     "mocha"
					     "nyc"
					     "rimraf"
					     "typescript"
					     "dtslint")))))))


    (home-page "https://github.com/paulmillr/readdirp")
    (synopsis "Recursive version of fs.readdir with streaming api.")
    (description "Recursive version of fs.readdir. Exposes a stream API and a promise API.")
    (license license:expat)))

(define-public node-chokidar
  (package
    (name "node-chokidar")
    (version "3.5.3")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/paulmillr/chokidar.git")
              (commit "3.5.3")))
        (file-name (git-file-name name version))
        (sha256 (base32 "0i43ybbm6jkzw0jrnbpj18m1npx6cxamznrwgxavawyxmx5z3wrx"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("@types/node"
					     "chai"
					     "chai-subset"
					     "eslint"
					     "mocha"
					     "rimraf"
					     "typescript"
					     "dtslint"
					     "nyc"
					     "sinon"
					     "sinon-chai"
					     "upath")))))))


    (inputs (list node-anymatch node-braces node-glob-parent node-is-binary-path node-is-glob node-normalize-path node-readdirp))
    (home-page "https://github.com/paulmillr/chokidar")
    (synopsis "Minimal and efficient cross-platform file watching library")
    (description "Minimal and efficient cross-platform file watching library")
    (license license:expat)))

(define-public node-glob-watcher
  (package
    (name "node-glob-watcher")
    (version "6.0.0")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/gulpjs/glob-watcher.git")
              (commit "v6.0.0")))
        (file-name (git-file-name name version))
        (sha256 (base32 "09m3k90is6wsnpyz9j2hj4dkq0pm5bil9677419jv22wzzw7fgr3"))))
    (build-system node-build-system)
    (inputs (list node-async-done node-chokidar))
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("eslint"
					     "eslint-config-gulp"
					     "expect"
					     "mocha"
					     "normalize-path"
					     "nyc"
					     "rimraf"
					     "sinon"
					     "through2")))))))


    (home-page "https://github.com/gulpjs/glob-watcher")
    (synopsis "Watch globs and execute a function upon change, with intelligent defaults for debouncing and queueing.")
    (description "Watch globs and execute a function upon change, with intelligent defaults for debouncing and queueing.")
    (license license:expat)))

(define-public node-chalk
  (package
    (name "node-chalk")
    (version "5.3.0")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/chalk/chalk.git")
              (commit "v5.3.0")))
        (file-name (git-file-name name version))
        (sha256 (base32 "0x6cgvsdlk9lpag95xcc0k5bih1dsn91al08ismy1qfv5wkvhqq4"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("@types/node"
					     "ava"
					     "c8"
					     "color-convert"
					     "execa"
					     "log-update"
					     "matcha"
					     "tsd"
					     "xo"
					     "yoctodelay")))))))


    (home-page "https://github.com/chalk/chalk")
    (synopsis "Terminal string styling done right")
    (description "Terminal string styling done right")
    (license license:expat)))

(define-public node-is-plain-object
  (package
    (name "node-is-plain-object")
    (version "5.0.0")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/jonschlinkert/is-plain-object.git")
              (commit "v5.0.0")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1s2klxw9d6482fjv788anlk3s22va2j3rvxjnhx4javnh5l8azi0"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (delete 'build)
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("chai"
					     "esm"
					     "gulp-format-md"
					     "mocha"
					     "mocha-headless-chrome"
					     "rollup")))))))


    (home-page "https://github.com/jonschlinkert/is-plain-object")
    (synopsis "Returns true if the given value is an object created by the Object constructor.")
    (description "Returns true if the given value is an object created by the Object constructor.")
    (license license:expat)))

(define-public node-array-each
  (package
    (name "node-array-each")
    (version "1.0.1")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/jonschlinkert/array-each.git")
              (commit "1.0.1")))
        (file-name (git-file-name name version))
        (sha256 (base32 "17915adrlcm2ghv1pjlyp7g77292wwwfxgmp4pcs8h8xjrbv96m0"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("gulp-format-md"
					     "mocha")))))))


    (home-page "https://github.com/jonschlinkert/array-each")
    (synopsis "Loop over each item in an array and call the given function on every element.")
    (description "Loop over each item in an array and call the given function on every element.")
    (license license:expat)))

(define-public node-array-slice
  (package
    (name "node-array-slice")
    (version "1.1.0")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/jonschlinkert/array-slice.git")
              (commit "1.1.0")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1v82a95vp0dqg9lry7i5y4r0d47922khh6xa5g5fqms3l74cna0r"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("gulp-format-md"
					     "mocha")))))))


    (home-page "https://github.com/jonschlinkert/array-slice")
    (synopsis "Lo-dash's array-clice method. Slices `array` from the `start` index up to, but not including, the `end` index.")
    (description "Lo-dash's array-clice method. Slices `array` from the `start` index up to, but not including, the `end` index.")
    (license license:expat)))

(define-public node-for-in
  (package
    (name "node-for-in")
    (version "1.0.2")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/jonschlinkert/for-in.git")
              (commit "1.0.2")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1d9r0rq64g2w7dgfpknrl30yln8b4a30nq62s03lflam8a6ymrx9"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("gulp-format-md"
					     "mocha")))))))


    (home-page "https://github.com/jonschlinkert/for-in")
    (synopsis "Iterate over the enumerable properties of an object, and return an object with properties that evaluate to true from the callback. Exit early by returning `false`.")
    (description "Iterate over the enumerable properties of an object, and return an object with properties that evaluate to true from the callback. Exit early by returning `false`.")
    (license license:expat)))

(define-public node-for-own
  (package
    (name "node-for-own")
    (version "1.0.0")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/jonschlinkert/for-own.git")
              (commit "1.0.0")))
        (file-name (git-file-name name version))
        (sha256 (base32 "07qk6dgjj2slgwrl58hhnl7bjispmm7indv6lv7dkhzd6wzigyl8"))))
    (build-system node-build-system)
    (inputs (list node-for-in))
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("gulp-format-md"
					     "mocha")))))))


    (home-page "https://github.com/jonschlinkert/for-own")
    (synopsis "Iterate over the own enumerable properties of an object, and return an object with properties that evaluate to true from the callback. Exit early by returning `false`.")
    (description "Iterate over the own enumerable properties of an object, and return an object with properties that evaluate to true from the callback. Exit early by returning `false`.")
    (license license:expat)))

(define-public node-isobject
  (package
    (name "node-isobject")
    (version "4.0.0")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/jonschlinkert/isobject.git")
              (commit "4.0.0")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1yni34vzmrgkl9q7vqigpplsbjffpqxd1z0r4l6lw7g2a6dpqcmq"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
				(delete 'build)
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("esm"
					     "gulp-format-md"
					     "mocha"
					     "rollup")))))))


    (home-page "https://github.com/jonschlinkert/isobject")
    (synopsis "Is the value an object, and not an array or null?")
    (description "Is the value an object, and not an array or null?")
    (license license:expat)))

;;doesn't work
(define-public node-definitelytyped
  (package
    (name "node-definitelytyped")
    (version "0.1.450")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/DefinitelyTyped/DefinitelyTyped.git")
              (commit "0.1.450")))
        (file-name (git-file-name name version))
        (sha256 (base32 "06zq8xpzbchaagb3lbcyn4gpqjmc2gsgnryfq6pqwmca3rjfpx0f"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("@definitelytyped/definitions-parser"
					     "@definitelytyped/dts-critic"
					     "@definitelytyped/dtslint"
					     "@definitelytyped/dtslint-runner"
					     "@definitelytyped/eslint-plugin"
					     "@definitelytyped/header-parser"
					     "@definitelytyped/typescript-versions"
					     "@definitelytyped/utils"
					     "danger"
					     "dprint"
					     "eslint-plugin-jsdoc"
					     "husky"
					     "dtslint"
					     "lint-staged"
					     "remark-cli"
					     "remark-gfm"
					     "remark-validate-links"
					     "typescript")))))))


    (home-page "https://github.com/DefinitelyTyped/DefinitelyTyped")
    (synopsis "The repository for high quality TypeScript type definitions.")
    (description "The repository for high quality TypeScript type definitions.")
    (license license:expat)))

;; doesn't work
(define-public node-definitelytyped-tools
  (package
    (name "node-definitelytyped-tools")
    (version "0.1.5")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/microsoft/DefinitelyTyped-tools.git")
              (commit "@definitelytyped/retag@0.1.5")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1a7s1drq2v6hkrn6n7r0yravcz9834y1ghp22ig17lpyaa14x5iw"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("@changesets/cli"
					     "@types/jest"
					     "@types/node"
					     "@types/yargs"
					     "@typescript-eslint/eslint-plugin"
					     "@typescript-eslint/parser"
					     "eslint"
					     "eslint-plugin-import"
					     "eslint-plugin-jsdoc"
					     "jest"
					     "knip"
					     "prettier"
					     "ts-jest"
					     "typescript")))))))


    (home-page "https://github.com/microsoft/DefinitelyTyped-tools")
    (synopsis "Infrastructure for DefinitelyTyped")
    (description "Infrastructure for DefinitelyTyped")
    (license license:expat)))

;;doesn't work
(define-public node-typescript
  (package
    (name "node-typescript")
    (version "5.3.3")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/microsoft/TypeScript.git")
              (commit "v5.3.3")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1xma9zvsy3jbk3xfg19lv2xwq25qp0fn8dfpfj7gcscv67hm55w1"))))
    (build-system node-build-system)
    (arguments 
      '(#:tests? #f
	#:phases (modify-phases %standard-phases
		  (add-after 'patch-dependencies 'delete-dependencies
                    (lambda _
                      (delete-dependencies '("@changesets/cli"
					     "@types/jest"
					     "@types/node"
					     "@types/yargs"
					     "@typescript-eslint/eslint-plugin"
					     "@typescript-eslint/parser"
					     "eslint"
					     "eslint-plugin-import"
					     "eslint-plugin-jsdoc"
					     "jest"
					     "knip"
					     "prettier"
					     "ts-jest"
					     "typescript")))))))


    (home-page "https://github.com/Microsoft/TypeScript")
    (synopsis "TypeScript is a superset of JavaScript that compiles to clean JavaScript output.")
    (description "TypeScript is a language for application-scale JavaScript. TypeScript adds optional types to JavaScript that support tools for large-scale JavaScript applications for any browser, for any host, on any OS. TypeScript compiles to readable, standards-based JavaScript.")
    (license license:asl2.0)))
